@@ -15,19 +15,18 @@ limitations under the License.
 
 """
 
-import json
 import os
 import time
 
 from oslo_log import log
 import requests
-from requests.packages.urllib3.exceptions import InsecureRequestWarning
+from requests.packages import urllib3
 
 from freezer.storage import physical
 
 LOG = log.getLogger(__name__)
 
-requests.packages.urllib3.disable_warnings(InsecureRequestWarning)
+urllib3.disable_warnings(urllib3.exceptions.InsecureRequestWarning)
 
 
 class SwiftStorage(physical.PhysicalStorage):
@@ -38,7 +37,7 @@ class SwiftStorage(physical.PhysicalStorage):
     _type = 'swift'
 
     def rmtree(self, path):
-        split = path.rsplit('/', 1)
+        split = path.split('/', 1)
         for file in self.swift().get_container(split[0],
                                                prefix=split[1])[1]:
             try:
@@ -134,19 +133,21 @@ class SwiftStorage(physical.PhysicalStorage):
             self.swift().put_container(self.storage_path)
 
     def info(self):
-        ordered_container = {}
         containers = self.swift().get_account()[1]
+        ordered_containers = []
         for container in containers:
-            print(container)
+            ordered_container = {}
             ordered_container['container_name'] = container['name']
-            size = '{0}'.format((int(container['bytes']) / 1024) / 1024)
-            if size == '0':
-                size = '1'
-            ordered_container['size'] = '{0}MB'.format(size)
+            size = (int(container['bytes']) / 1024) / 1024
+            if size == 0:
+                size = 1
+            ordered_container['size'] = '{0} MB'.format(size)
+            if size >= 1024:
+                size /= 1024
+                ordered_container['size'] = '{0} GB'.format(size)
             ordered_container['objects_count'] = container['count']
-            print(json.dumps(
-                ordered_container, indent=4,
-                separators=(',', ': '), sort_keys=True))
+            ordered_containers.append(ordered_container)
+        return ordered_containers
 
     def get_file(self, from_path, to_path):
         split = from_path.split('/', 1)
@@ -225,12 +226,14 @@ class SwiftStorage(physical.PhysicalStorage):
             # split[0] = freezer_backups which is container name
             # split[1] = tar/server1.cloud.com_testest/
             split = path.split('/', 1)
-            files = self.swift().get_container(container=split[0],
-                                               full_listing=True,
-                                               prefix=split[1])[1]
+            files = self.swift().get_container(
+                container=split[0],
+                full_listing=True,
+                prefix="{0}/".format(split[1]),
+                delimiter='/')[1]
             # @todo normalize intro plain for loop to be easily
             # understandable (szaher)
-            return set(f['name'][len(split[1]):].split('/', 2)[1] for f in
+            return set(f['subdir'].rsplit('/', 2)[1] for f in
                        files)
         except Exception as e:
             LOG.info(e)
