@@ -30,12 +30,10 @@ class TestJob(commons.FreezerBaseTestCase):
     def test_execute(self):
         opt = commons.BackupOpt1()
         job = jobs.InfoJob(opt, opt.storage)
-        assert job.execute() is None
+        assert job.execute() is not None
 
 
 class TestInfoJob(TestJob):
-    def setUp(self):
-        super(TestInfoJob, self).setUp()
 
     def test_execute_nothing_to_do(self):
         backup_opt = commons.BackupOpt1()
